# IMPERIUMS DASHBOARD
A simple commandline app for create project 
# Installation
## Using Pip
```bash
  $ pip install imp-cli
```
## Manual
```bash
  $ git clone https://github.com/JohanBustos/imperiums-cli-dashboard
  $ cd cver
  $ python setup.py install
```
## Autors
Johan Manuel Bustos Mendoza - johan.bustosm@gmail.com